!  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
!  The RELCONV MODEL (written by Thomas Dauser)
!  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
!  If you use this model for a publication, please cite our paper
!  "Dauser, Thomas; Wilms, J.; Reynolds, C. S.; Brenneman, L. W.,
!  2010, MNRAS, 409, 1534-1540"
!  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
!  This code, used together with relbase.f90, calculates relativistic
!  line profiles and is desinged to be used within a X-ray data
!  analysis program like XSPEC or ISIS.
! 
!
!  See www.sternwarte.uni-erlangen.de/research/relline/ or 
!  "relbase.f90" for information on the RELLINE model
!  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++


!  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
SUBROUTINE tdrelline(EAR,NE,PARAM,IFL,PHOTAR)
!  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  ! Main Routine for the RELLINE-model
  !--------------------------------------------------
  ! parameters required by XSPEC
  use par
  integer, parameter :: num_param = 10
  integer :: NE,IFL
  real  :: EAR(0:NE), PHOTAR(NE)
  real :: param(num_param)
  
  ! model type ?
  model_type = 1

  ! call the base routine
  no_caching_relline = .false. ! IMPORTANT
  call relbase(EAR,NE,PARAM,PHOTAR,NUM_PARAM)
  
END SUBROUTINE tdrelline !  ++++++++++++++++++++++++++++++++++++++++++++



!  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
SUBROUTINE tdrellinelp(EAR,NE,PARAM,IFL,PHOTAR)
!  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  ! Main Routine for the RELLINE_LP-model
  !--------------------------------------------------
  ! parameters required by XSPEC
  use par
  integer, parameter :: num_param = 9
  integer :: NE,IFL
  real  :: EAR(0:NE), PHOTAR(NE)
  real :: param(num_param)
  
  ! model type ?
  model_type = 2

  ! call the base routine
  no_caching_relline = .false.  ! IMPORTANT
  call relbase(EAR,NE,PARAM,PHOTAR,NUM_PARAM)
  
END SUBROUTINE tdrellinelp



!  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
SUBROUTINE tdrellinelpext(EAR,NE,PARAM,IFL,PHOTAR)
!  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  ! Main Routine for the RELLINE_LP-model
  !--------------------------------------------------
  ! parameters required by XSPEC
  use par
  implicit none
  integer, parameter :: num_param = 12
  integer :: NE,IFL
  real  :: EAR(0:NE), PHOTAR(NE)
  real :: param(num_param)
  
  ! model type ?
  model_type = 3
  
  ! call the base routine
  no_caching_relline = .false.  ! IMPORTANT
  call relbase(EAR,NE,PARAM,PHOTAR,NUM_PARAM)
  
END SUBROUTINE tdrellinelpext
